@@ -26,8 +26,14 @@ class ViewBase(ConfigBase):
     | __field_widget_types__            | A dictionary of types of widgets, allowing | {}                           |
     |                                   | sprox to determine the widget args         |                              |
     +-----------------------------------+--------------------------------------------+------------------------------+
+    | __field_widget_args__             | A dictionary of types of args for widgets, | {}                           |
+    |                                   | you to override the args sent to the fields|                              |
+    +-----------------------------------+--------------------------------------------+------------------------------+
     | __base_widget_type__              | The base widget for this config            | Widget                       |
     +-----------------------------------+--------------------------------------------+------------------------------+
+    | __base_widget_args__              | Args to pass into the widget overrides any | {}                           |
+    |                                   | defaults that are set in sprox creation    |                              |
+    +-----------------------------------+--------------------------------------------+------------------------------+
     | __widget_selector__               | an instantiated object to use for widget   | None                         |
     |                                   | selection.                                 |                              |
     +-----------------------------------+--------------------------------------------+------------------------------+
@@ -36,18 +42,24 @@ class ViewBase(ConfigBase):
     """
     __field_widgets__      = None
     __field_widget_types__ = None
+    __field_widget_args__  = None
     __ignore_field_names__ = None
 
     #object overrides
     __base_widget_type__       = Widget
+    __base_widget_args__       = None
     __widget_selector_type__   = WidgetSelector
     __widget_selector__        = None
 
 
     def _do_init_attrs(self):
         super(ViewBase, self)._do_init_attrs()
+        if self.__base_widget_args__ is None:
+            self.__base_widget_args__ = {}
         if self.__field_widgets__ is None:
             self.__field_widgets__ = {}
+        if self.__field_widget_args__ is None:
+            self.__field_widget_args__ = {}
         if self.__field_widget_types__ is None:
             self.__field_widget_types__ = {}
         if self.__widget_selector__ is None:
@@ -95,6 +107,7 @@ class ViewBase(ConfigBase):
             field_widgets.append(value)
 
         d = dict(children=field_widgets)
+        d.update(self.__base_widget_args__)
         return d
 
     def _do_get_disabled_fields(self):
@@ -120,6 +133,8 @@ class ViewBase(ConfigBase):
             args['provider'] = self.__provider__
             args['nullable'] = self.__provider__.is_nullable(self.__entity__, field_name)
 
+        if field_name in self.__field_widget_args__:
+            args.update(self.__field_widget_args__[field_name])
         return args
 
     def __create_hidden_fields(self):
@@ -128,7 +143,10 @@ class ViewBase(ConfigBase):
 
         for field in self.__hide_fields__:
             if field not in self.__omit_fields__:
-                fields[field] = HiddenField(id=field, identifier=field)
+                args = {}
+                if field in self.__field_widget_args__:
+                    args.update(self.__field_widget_args__[field])
+                fields[field] = HiddenField(id=field, identifier=field, **args)
 
         return fields
 
